summaryrefslogtreecommitdiff
path: root/indra/newview/viewer_manifest.py
diff options
context:
space:
mode:
authorOz Linden <oz@lindenlab.com>2020-08-25 11:59:27 -0400
committerOz Linden <oz@lindenlab.com>2020-08-25 11:59:27 -0400
commit6a9c89fd62ee458dff4f2ade76d44947b99e472a (patch)
tree717925077f35ddb370727a5dd931105548e3e86d /indra/newview/viewer_manifest.py
parenta9d271c5a26306486045293e9fe7941e3b72e370 (diff)
SL-10297 do not package win_crash_logger executable if using BugSplat
Diffstat (limited to 'indra/newview/viewer_manifest.py')
-rwxr-xr-xindra/newview/viewer_manifest.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/indra/newview/viewer_manifest.py b/indra/newview/viewer_manifest.py
index 2105b419e7..c636f1d910 100755
--- a/indra/newview/viewer_manifest.py
+++ b/indra/newview/viewer_manifest.py
@@ -673,10 +673,11 @@ class WindowsManifest(ViewerManifest):
self.path("libvlccore.dll")
self.path("plugins/")
- # pull in the crash logger from other projects
- # tag:"crash-logger" here as a cue to the exporter
- self.path(src='../win_crash_logger/%s/windows-crash-logger.exe' % self.args['configuration'],
- dst="win_crash_logger.exe")
+ if not bugsplat_db: # don't include the win_crash_logger if we are using BugSplat
+ # pull in the crash logger from other projects
+ # tag:"crash-logger" here as a cue to the exporter
+ self.path(src='../win_crash_logger/%s/windows-crash-logger.exe' % self.args['configuration'],
+ dst="win_crash_logger.exe")
if not self.is_packaging_viewer():
self.package_file = "copied_deps"